==> kameleoon_client_flutter-0.0.1.tar.gz: example/lib/Pages/Signup/signup_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:kameleoon_client_flutter/kameleoon_client.dart';
import 'package:kameleoon_client_flutter/kameleoon_exceptions.dart' as KameleoonExceptions;
import 'package:kameleoon_client_flutter/kameleoon_data.dart' as KameleoonData;
import 'package:kameleoon_client_flutter_example/Components/Button.dart';
import 'package:kameleoon_client_flutter_example/Pages/Login/login_page.dart';
import 'package:flutter_svg/flutter_svg.dart';

import '../../constants.dart';
import 'package:kameleoon_client_flutter_example/Components/KTextInput.dart';

class SignupPage extends StatefulWidget {
  @override
  _SignupPage createState() => _SignupPage();
}

class _SignupPage extends State<SignupPage> {
  bool canShowSocial = true;

  @override
  void initState() {
    super.initState();
    initKameleoon();
  }

  Future<void> initKameleoon() async {
    KameleoonClient client = await KameleoonClient.create("yjiu8jw554");

    client.runWhenReady(() async {
      String visitorCode = await client.obtainVisitorCode();
      try {
        bool ff = await client.activateFeature(visitorCode, "color-feature-flag");
        if (ff) {
          String color = await client.obtainFeatureVariable("color-feature-flag", "color");
          color = "FF" + color.toUpperCase().replaceAll("#", "");
          //mainColor = Color(int.parse(color, radix: 16));
        }
      } on KameleoonExceptions.FeatureConfigurationNotFound {
      } on KameleoonExceptions.NotTargeted {
      } on PlatformException {
      }

      try {
        await client.addData(visitorCode, new KameleoonData.CustomData(30, "123456789"));
        bool showSocial = await client.activateFeature(visitorCode, "show-social");
        setState(() {
          canShowSocial = true;
        });
      } on KameleoonExceptions.FeatureConfigurationNotFound {
      } on KameleoonExceptions.NotTargeted {
        print("Not targeted");
      }
    }, () {}, 5000);
  }

  @override
  Widget build(BuildContext context) {
    Size screenSize = MediaQuery.of(context).size;
    return Scaffold(
        body: Container(
            width: screenSize.width,
            height: screenSize.height,
            child: Column(
              children: <Widget>[
                Padding(
                    padding: EdgeInsets.only(bottom: 20, top: 70),
                    child: Image.asset(
                      "assets/images/logo.png",
                    )
                ),
                Text(
                  "Welcome!",
                  style: TextStyle(
                    fontWeight: FontWeight.bold,
                    fontSize: 24,
                  ),
                ),
                Padding(
                    padding: EdgeInsets.only(top: 10, bottom: 50),
                    child: Text(
                        "Sign up to create your account",
                        style: TextStyle(
                            fontWeight: FontWeight.w400,
                            fontSize: 17
                        )
                    )
                ),
                Text(
                    "Username or e-mail address",
                    textAlign: TextAlign.left,
                    style: TextStyle(
                        fontWeight: FontWeight.bold,
                        fontSize: 14
                    )
                ),
                Padding(
                    padding: EdgeInsets.only(bottom: 20, top: 5),
                    child: KTextInput(
                        suffixIcon: false,
                        icon: Icons.person,
                        hint: "Username or Email"
                    )
                ),
                Text(
                    "Password",
                    textAlign: TextAlign.left,
                    style: TextStyle(
                        fontWeight: FontWeight.bold,
                        fontSize: 14
                    )
                ),
                Padding(
                    padding: EdgeInsets.only(bottom: 30, top: 5),
                    child: KTextInput(
                        suffixIcon: true,
                        icon: Icons.lock,
                        hint: "Password"
                    )
                ),
                Button(
                  text: "Sign up",
                  bgColor: mainColor,
                  borderColor: mainColor,
                  borderWidth: 0,
                  borderStyle: BorderStyle.none,
                  textColor: Colors.white,
                ),
                Padding(
                  padding: EdgeInsets.only(top: 5),
                  child: Button(
                    text: "Already have an Account? Sign in",
                    bgColor: Colors.transparent,
                    borderColor: mainColor,
                    borderWidth: 0,
                    borderStyle: BorderStyle.none,
                    textColor: Color.fromRGBO(0, 0, 0, 0.5),
                    onPress: () {
                      Navigator.push(
                          context, MaterialPageRoute(builder: (context) {
                        return LoginPage();
                      }));
                    }
                  ),
                ),
                Container(
                  child: canShowSocial ? OrDivider() : null
                ),
                Container(
                    child: canShowSocial ? Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: <Widget>[
                        SocalIcon(
                          iconSrc: "assets/icons/facebook.svg",
                          press: () {},
                        ),
                        SocalIcon(
                          iconSrc: "assets/icons/twitter.svg",
                          press: () {},
                        ),
                        SocalIcon(
                          iconSrc: "assets/icons/google-plus.svg",
                          press: () {},
                        ),
                      ],
                    ) : null
                )
              ],
            )
        )
    );
  }
}

class OrDivider extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Container(
      margin: EdgeInsets.symmetric(vertical: size.height * 0.02),
      width: size.width * 0.8,
      child: Row(
        children: <Widget>[
          buildDivider(),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 10),
            child: Text(
              "OR",
              style: TextStyle(
                color: mainColor,
                fontWeight: FontWeight.w600,
              ),
            ),
          ),
          buildDivider(),
        ],
      ),
    );
  }

  Expanded buildDivider() {
    return Expanded(
      child: Divider(
        color: Color(0xFFD9D9D9),
        height: 1.5,
      ),
    );
  }
}

class SocalIcon extends StatelessWidget {
  final String iconSrc;
  final Function press;
  const SocalIcon({
    Key key,
    this.iconSrc,
    this.press,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: press,
      child: Container(
        margin: EdgeInsets.symmetric(horizontal: 10),
        padding: EdgeInsets.all(20),
        decoration: BoxDecoration(
          border: Border.all(
            width: 2,
            color: mainColor,
          ),
          shape: BoxShape.circle,
        ),
        child: SvgPicture.asset(
          iconSrc,
          height: 20,
          width: 20,
          color: mainColor,
        ),
      ),
    );
  }
}

==> kameleoon_client_flutter-1.0.3.tar.gz: example/lib/Pages/Signup/signup_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:kameleoon_client_flutter/kameleoon_client_flutter.dart';
import 'package:kameleoon_client_flutter_example/Components/Button.dart';
import 'package:kameleoon_client_flutter_example/Pages/Login/login_page.dart';
import 'package:flutter_svg/flutter_svg.dart';

import '../../constants.dart';
import 'package:kameleoon_client_flutter_example/Components/KTextInput.dart';

class SignupPage extends StatefulWidget {
  @override
  _SignupPage createState() => _SignupPage();
}

class _SignupPage extends State<SignupPage> {
  bool canShowSocial = false;
  Color _color = Color.fromRGBO(100, 100, 255, 1);

  @override
  void initState() {
    super.initState();
    initKameleoon();
  }

  Future<void> initKameleoon() async {
    KameleoonClient? client = KameleoonClientFactory.create("yjiu8jw554");

    client!.runWhenReady(() async {
      String? visitorCode = await client.obtainVisitorCode();
      try {
        bool? ff = await client.activateFeature(visitorCode!, "color-feature-flag");
        if (ff == true) {
          String? color = await client.obtainFeatureVariable("color-feature-flag", "color") as String?;
          color = "FF" + color!.toUpperCase().replaceAll("#", "");
          mainColor = Color(int.parse(color, radix: 16));
          setState(() {
            _color = mainColor;
          });
        }
      } on FeatureConfigurationNotFound {
      } on NotTargeted {
      } on PlatformException {
      }

      try {
        await client.addData(visitorCode!, new CustomData(30, "9876543210"));
        bool? showSocial = await client.activateFeature(visitorCode, "show-social");
        setState(() {
          canShowSocial = showSocial!;
        });
      } on FeatureConfigurationNotFound {
      } on NotTargeted {
        print("Not targeted");
      }
    }, () {}, 5000);
  }

  @override
  Widget build(BuildContext context) {
    Size screenSize = MediaQuery.of(context).size;
    return Scaffold(
        body: Container(
            width: screenSize.width,
            height: screenSize.height,
            child: Column(
              children: <Widget>[
                Padding(
                    padding: EdgeInsets.only(bottom: 20, top: 70),
                    child: Image.asset(
                      "assets/images/logo.png",
                    )
                ),
                Text(
                  "Welcome!",
                  style: TextStyle(
                    fontWeight: FontWeight.bold,
                    fontSize: 24,
                  ),
                ),
                Padding(
                    padding: EdgeInsets.only(top: 10, bottom: 50),
                    child: Text(
                        "Sign up to create your account",
                        style: TextStyle(
                            fontWeight: FontWeight.w400,
                            fontSize: 17
                        )
                    )
                ),
                Text(
                    "Username or e-mail address",
                    textAlign: TextAlign.left,
                    style: TextStyle(
                        fontWeight: FontWeight.bold,
                        fontSize: 14
                    )
                ),
                Padding(
                    padding: EdgeInsets.only(bottom: 20, top: 5),
                    child: KTextInput(
                        suffixIcon: false,
                        icon: Icons.person,
                        hint: "Username or Email"
                    )
                ),
                Text(
                    "Password",
                    textAlign: TextAlign.left,
                    style: TextStyle(
                        fontWeight: FontWeight.bold,
                        fontSize: 14
                    )
                ),
                Padding(
                    padding: EdgeInsets.only(bottom: 30, top: 5),
                    child: KTextInput(
                        suffixIcon: true,
                        icon: Icons.lock,
                        hint: "Password"
                    )
                ),
                Button(
                  text: "Sign up",
                  bgColor: _color,
                  borderColor: _color,
                  borderWidth: 0,
                  borderStyle: BorderStyle.none,
                  textColor: Colors.white,
                ),
                Padding(
                  padding: EdgeInsets.only(top: 5),
                  child: Button(
                    text: "Already have an Account? Sign in",
                    bgColor: Colors.transparent,
                    borderColor: _color,
                    borderWidth: 0,
                    borderStyle: BorderStyle.none,
                    textColor: Color.fromRGBO(0, 0, 0, 0.5),
                    onPress: () {
                      Navigator.push(
                          context, MaterialPageRoute(builder: (context) {
                        return LoginPage();
                      }));
                    }
                  ),
                ),
                Container(
                  child: canShowSocial ? OrDivider() : null
                ),
                Container(
                    child: canShowSocial ? Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: <Widget>[
                        SocalIcon(
                          iconSrc: "assets/icons/facebook.svg",
                          press: () {}, key: Key("1"),
                        ),
                        SocalIcon(
                          iconSrc: "assets/icons/twitter.svg",
                          press: () {}, key: Key("2"),
                        ),
                        SocalIcon(
                          iconSrc: "assets/icons/google-plus.svg",
                          press: () {}, key: Key("3"),
                        ),
                      ],
                    ) : null
                )
              ],
            )
        )
    );
  }
}

class OrDivider extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Container(
      margin: EdgeInsets.symmetric(vertical: size.height * 0.02),
      width: size.width * 0.8,
      child: Row(
        children: <Widget>[
          buildDivider(),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 10),
            child: Text(
              "OR",
              style: TextStyle(
                color: mainColor,
                fontWeight: FontWeight.w600,
              ),
            ),
          ),
          buildDivider(),
        ],
      ),
    );
  }

  Expanded buildDivider() {
    return Expanded(
      child: Divider(
        color: Color(0xFFD9D9D9),
        height: 1.5,
      ),
    );
  }
}

class SocalIcon extends StatelessWidget {
  final String iconSrc;
  final Function press;
  const SocalIcon({
    required Key key,
    required this.iconSrc,
    required this.press,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      child: Container(
        margin: EdgeInsets.symmetric(horizontal: 10),
        padding: EdgeInsets.all(20),
        decoration: BoxDecoration(
          border: Border.all(
            width: 2,
            color: mainColor,
          ),
          shape: BoxShape.circle,
        ),
        child: SvgPicture.asset(
          iconSrc,
          height: 20,
          width: 20,
          color: mainColor,
        ),
      ),
    );
  }
}
